@@ -1,14 +1,12 @@
 package DBM::Deep::Sector::DBI::Reference;
 
-use 5.008_000;
+use 5.006_000;
 
 use strict;
 use warnings FATAL => 'all';
 
 use base 'DBM::Deep::Sector::DBI';
 
-use Scalar::Util;
-
 sub table { 'refs' }
 
 sub _init {
@@ -92,12 +90,6 @@ sub delete_key {
     my $data;
     if ( $old_value ) {
         $data = $old_value->data({ export => 1 });
-
-        $self->engine->storage->delete_from(
-            'datas',
-             { ref_id => $self->offset,
-               key => $args->{key},  },
-        );
         $old_value->free;
     }
 
@@ -121,25 +113,17 @@ sub data {
     $args ||= {};
 
     my $engine = $self->engine;
-    my $cache = $engine->cache;
-    my $off = $self->offset;
-    my $obj;
-    if ( !defined $cache->{ $off } ) {
-        $obj = DBM::Deep->new({
+    if ( !exists $engine->cache->{ $self->offset } ) {
+        my $obj = DBM::Deep->new({
             type        => $self->type,
             base_offset => $self->offset,
             storage     => $engine->storage,
             engine      => $engine,
         });
 
-        $cache->{$off} = $obj;
-        if($engine->{external_refs}) {
-            Scalar::Util::weaken($cache->{$off});
-        }
-    }
-    else {
-        $obj = $cache->{$off};
+        $engine->cache->{$self->offset} = $obj;
     }
+    my $obj = $engine->cache->{$self->offset};
 
     # We're not exporting, so just return.
     unless ( $args->{export} ) {
@@ -168,21 +152,16 @@ sub free {
     return if $self->decrement_refcount > 0;
 
     # Rebless the object into DBM::Deep::Null.
-    # In external_refs mode, this will already have been removed from
-    # the cache, so we can skip this.
-    my $e  = $self->engine;
-    if(!$e->{external_refs}) {
-        eval { %{ $e->cache->{ $self->offset } } = (); };
-        eval { @{ $e->cache->{ $self->offset } } = (); };
-        bless $e->cache->{ $self->offset }, 'DBM::Deep::Null';
-        delete $e->cache->{ $self->offset };
-    }
+    eval { %{ $self->engine->cache->{ $self->offset } } = (); };
+    eval { @{ $self->engine->cache->{ $self->offset } } = (); };
+    bless $self->engine->cache->{ $self->offset }, 'DBM::Deep::Null';
+    delete $self->engine->cache->{ $self->offset };
 
-    $e->storage->delete_from(
+    $self->engine->storage->delete_from(
         'datas', { ref_id => $self->offset },
     );
 
-    $e->storage->delete_from(
+    $self->engine->storage->delete_from(
         'datas', { value => $self->offset, data_type => 'R' },
     );
 
