@@ -28,7 +28,7 @@ my %is_dev = (
 my %opts = (
   man => 0,
   help => 0,
-  version => '1.0013',
+  version => '1.0014',
   autobless => 1,
 );
 GetOptions( \%opts,
@@ -71,16 +71,16 @@ my %db;
 
 {
   my $ver = $opts{version};
-  if ( $ver =~ /^1\.001[0-3]/) {
+  if ( $ver =~ /^1\.001[0-4]/ ) {
     $ver = 3;
   }
-  elsif ( $ver =~ /^1\.000[3-9]/) {
+  elsif ( $ver =~ /^1\.000[3-9]/ ) {
     $ver = 3;
   }
-  elsif ( $ver =~ /^1\.000?[0-2]?/) {
+  elsif ( $ver eq '1.00' || $ver eq '1.000' || $ver =~ /^1\.000[0-2]/ ) {
     $ver = 2;
   }
-  elsif ( $ver =~ /^0\.99/) { 
+  elsif ( $ver =~ /^0\.99/ ) { 
     $ver = 1;
   }
   elsif ( $ver =~ /^0\.9[1-8]/ ) {
